#!/bin/sh

[ -n "$include_widgets" ] && return 0
include_widgets="$0"

. "$_EXEC/cgilite/storage.sh"

w_refuri="$(HTML "$REQUEST_URI")"

w_tags="$(find "$_DATA/" -path '*/.index/meta' -print0 \
        | xargs -r0 sed -r '
          s;^.*\t.*\t.*\ttags=(.*)\tcomment=.*\t.*\r$;\1;;
          s;,;\n;g;'"$UNSTRING" \
        | sort -u |HTML |sed 's;&#58\;;:;g; s;&#10\;;\n;g;')"
w_tagcategories="$(printf %s "$w_tags" | cut -sd: -f1 | uniq)"

[ "$ORDER" = Name   ] && w_coname=checked
[ "$ORDER" = Date   ] && w_codate=checked
[ "$ORDER" = Length ] && w_colength=checked

w_bookmarks(){
  local name link bm
  bm="$_DATA/.index/bookmarks"

  printf '[form #bookmarks action=?a=bookmarks method=POST
            [a href="#" X]
            [hidden "ref" "%s"]
          ' "$w_refuri"

  name="$(grep -m1 -F "	$(STRING "${REQUEST_URI}")" "$bm")"
  printf '[hidden "link" "%s"][input name="name" value="%s"]' \
         "$(HTML "$link")" "$(HTML "$name")"

  sort "$bm" |while read -r name link; do
    name="$(UNSTRING "$name")"
    link="$(UNSTRING "$link")"
    if [ "$link" != "$REQUEST_URI" ]; then
      printf '[a href="%s"\n%s]' "$(HTML "$link")" "$(HTML "$name")"
    fi
  done
  printf ']'
}

w_search(){
  printf '
  [form #search method=GET action=?
    [select name=o size=1 
      [option disabled=disabled Order By]
      [option value=Name %s Name]
      [option value=Date %s Date]
      [option value=Length %s Length]
    ]
    [input name=s placeholder=Search value="%s"]
  ]
  ' \
  "$w_coname" "$w_codate" "$w_colength" \
  "$(HTML "$SEARCH")"
}

w_prefs(){
  local tm tf

  tm=''; [ "$(COOKIE mode)" = index ] && tm=' '
  tf=''; [ "$(COOKIE fakemp4)" = yes ] && tf=checked

  printf '
  [form #prefs method="POST" action="?a=setprefs"
    [a href="#" x]
    [hidden "ref" "%s"]
    [label for=prefs_ps Pagesize]
    [input #prefs_ps type=number name=pagesize value="%s"][br]
    [radio "mode" "browse" %s #prefs_modebrowse] [label for=prefs_modebrowse Browse Folders][br]
    [radio "mode" "index"  %s #prefs_modeindex ] [label for=prefs_modeindex View Full Index][br]
    [checkbox "fakemp4" "yes" %s #prefs_fmp4] [label for=prefs_fmp4 Fake .MP4 file ending][br]
    [submit "store" "store" Set Cookie]
  ]
  ' \
  "$w_refuri" "$LISTSIZE" \
  "${tm:-checked}" "${tm:+checked}" "$tf"
}

w_index(){
  [ -d "$_DATA/$ITEM/.index" ] || printf '
  [form #index method="POST" action="?a=spawnindex"
    [hidden "ref" "%s"]
    [label Set up for Index view: ]
    [checkbox "recursive" "yes" #spawn_recursive] [label for=spawn_recursive Include subdirectories]
    [submit "spawn" "spawn" Set up]
  ]
  ' "$w_refuri"
}

w_advsearch(){
  local n lbid tag category filter f t
  filter="$(HTML "${FILTER}^" |sed 's;&#126\;;~;g; s;&#94\;;^;g; s;&#124\;;|;g; s;&#58\;;:;g;')"

  printf '[form #advsearch action=?a=advsearch method=POST
            [a href="#" Hide]
            [p .help Select multiple tags from each category by holding down the [strong Ctrl] key on your keyboard.[br]
            Refine the search further by setting additional search tags using the [strong "+and"] button.]'

  for n in 1 2 3 4 5 6 7 8 9 10; do
    f="${filter%%^*}"; filter="${filter#*^}"

    t=''; [ "$f" -a ! "${f%%~*}" ] && t=" "

    lbid="cat_${n}_(none)"
    printf '[input .and type=checkbox name=and id="and_%i" %s][label for="and_%i" +and
            ][fieldset .select
            [radio "pol_%i" "pos" .pol %s #pol_pos_%i"][label for=pol_pos_%i Any]
            [radio "pol_%i" "neg" .pol %s #pol_neg_%i"][label for=pol_neg_%i None]
            [label .head Category:]' \
            $n "${f:+checked}" $n \
            $n "${t:-checked}" $n $n \
            $n "${t:+checked}" $n $n

    f="|${f#~}|"
    printf '*\n%s\n' "$w_tagcategories" \
    | while read -r category; do
      lbid="cat_${n}_${category}"

      t=''
      [ "$category"  = '*' -a   "${f%%|${category}:*}" ] && t=checked
      [ "$category" != '*' -a ! "${f%%|${category}:*}" ] && t=checked

      printf '[radio "cat_%i" "%s" .cat %s id="%s"][label for="%s" %s]
              [select name=tag_%s size=10 multiple' \
              $n "$category" "$t" "$lbid" "$lbid" "$category" $n

      printf '%s\n' "$w_tags" \
      | { [ "$category" = '*' ] && grep -vF ':' |grep -vxF '' || grep -wF "${category}"; } \
      | while read -r tag; do
        t=''; [ ! "${f%%*|${tag}|*}" ] && t=checked
        printf '[option %s value="%s"\n%s]' "$t" "$tag" "${tag#*:}"
      done
      printf '\n]'
    done
    printf ']'
  done

  printf '[fieldset .submit [select name=order
            [option disabled=disabled Order By]
            [option value=Name %s Name]
            [option value=Date %s Date]
            [option value=Length %s Length]
          ][button type=submit Apply Filter]]
          ]' \
          "$w_coname" \
          "$w_codate" \
          "$w_colength"
}

w_tagging(){
  local tag category
  printf '[div #multitag [input type="hidden" name="ref" value="%s"]' "$w_refuri"
  printf '[a href="#" Hide][br]'

  printf 'Tags\n%s\n' "$w_tagcategories" \
  | while read -r category; do
    printf '[fieldset [legend %s:][select name=tag size=4 multiple' "$category"
    printf %s "$w_tags" \
    | { [ "$category" = 'Tags' ] && grep -vF ':' | grep -vxF '' || grep -wF "${category}"; } \
    | while read -r tag; do
      printf '[option value="%s"\n%s]' "$tag" "${tag#*:}"
    done
    printf ']]'
  done

  printf '[fieldset [legend New:][textarea name=newtag\n][button type=Submit Add Tags]]]'
}
